You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@poi.apache.org by fa...@apache.org on 2021/12/01 11:33:25 UTC

svn commit: r1895452 - in /poi/trunk: poi-ooxml/src/test/java/org/apache/poi/ooxml/ poi-scratchpad/src/main/java/org/apache/poi/hslf/usermodel/ poi-scratchpad/src/main/java/org/apache/poi/hwpf/ poi-scratchpad/src/test/java/org/apache/poi/hslf/extractor...

Author: fanningpj
Date: Wed Dec  1 11:33:25 2021
New Revision: 1895452

URL: http://svn.apache.org/viewvc?rev=1895452&view=rev
Log:
spelling of embedded

Modified:
    poi/trunk/poi-ooxml/src/test/java/org/apache/poi/ooxml/TestEmbedded.java
    poi/trunk/poi-scratchpad/src/main/java/org/apache/poi/hslf/usermodel/HSLFSlideShowImpl.java
    poi/trunk/poi-scratchpad/src/main/java/org/apache/poi/hwpf/HWPFDocument.java
    poi/trunk/poi-scratchpad/src/main/java/org/apache/poi/hwpf/HWPFDocumentCore.java
    poi/trunk/poi-scratchpad/src/test/java/org/apache/poi/hslf/extractor/TestExtractor.java
    poi/trunk/poi-scratchpad/src/test/java/org/apache/poi/hwpf/usermodel/TestPictures.java
    poi/trunk/poi/src/test/java/org/apache/poi/hssf/extractor/TestExcelExtractor.java

Modified: poi/trunk/poi-ooxml/src/test/java/org/apache/poi/ooxml/TestEmbedded.java
URL: http://svn.apache.org/viewvc/poi/trunk/poi-ooxml/src/test/java/org/apache/poi/ooxml/TestEmbedded.java?rev=1895452&r1=1895451&r2=1895452&view=diff
==============================================================================
--- poi/trunk/poi-ooxml/src/test/java/org/apache/poi/ooxml/TestEmbedded.java (original)
+++ poi/trunk/poi-ooxml/src/test/java/org/apache/poi/ooxml/TestEmbedded.java Wed Dec  1 11:33:25 2021
@@ -33,7 +33,7 @@ import org.apache.poi.xwpf.usermodel.XWP
 import org.junit.jupiter.api.Test;
 
 /**
- * Class to test that we handle embeded bits in OOXML files properly
+ * Class to test that we handle embedded bits in OOXML files properly
  */
 class TestEmbedded {
     @Test

Modified: poi/trunk/poi-scratchpad/src/main/java/org/apache/poi/hslf/usermodel/HSLFSlideShowImpl.java
URL: http://svn.apache.org/viewvc/poi/trunk/poi-scratchpad/src/main/java/org/apache/poi/hslf/usermodel/HSLFSlideShowImpl.java?rev=1895452&r1=1895451&r2=1895452&view=diff
==============================================================================
--- poi/trunk/poi-scratchpad/src/main/java/org/apache/poi/hslf/usermodel/HSLFSlideShowImpl.java (original)
+++ poi/trunk/poi-scratchpad/src/main/java/org/apache/poi/hslf/usermodel/HSLFSlideShowImpl.java Wed Dec  1 11:33:25 2021
@@ -718,7 +718,7 @@ public final class HSLFSlideShowImpl ext
     /**
      * Writes out the slideshow file the is represented by an instance
      * of this class.
-     * If you require all streams to be written out (eg Marcos, embeded
+     * If you require all streams to be written out (eg Marcos, embedded
      * documents), then set {@code preserveNodes} set to {@code true}
      *
      * @param newFile       The File to write to.
@@ -757,7 +757,7 @@ public final class HSLFSlideShowImpl ext
     /**
      * Writes out the slideshow file the is represented by an instance
      * of this class.
-     * If you require all streams to be written out (eg Marcos, embeded
+     * If you require all streams to be written out (eg Macros, embedded
      * documents), then set {@code preserveNodes} set to {@code true}
      *
      * @param out           The OutputStream to write to.

Modified: poi/trunk/poi-scratchpad/src/main/java/org/apache/poi/hwpf/HWPFDocument.java
URL: http://svn.apache.org/viewvc/poi/trunk/poi-scratchpad/src/main/java/org/apache/poi/hwpf/HWPFDocument.java?rev=1895452&r1=1895451&r2=1895452&view=diff
==============================================================================
--- poi/trunk/poi-scratchpad/src/main/java/org/apache/poi/hwpf/HWPFDocument.java (original)
+++ poi/trunk/poi-scratchpad/src/main/java/org/apache/poi/hwpf/HWPFDocument.java Wed Dec  1 11:33:25 2021
@@ -234,7 +234,7 @@ public final class HWPFDocument extends
     /**
      * This constructor loads a Word document from a specific point
      * in a POIFSFileSystem, probably not the default.
-     * Used typically to open embeded documents.
+     * Used typically to open embedded documents.
      *
      * @param directory The DirectoryNode that contains the Word document.
      * @throws IOException If there is an unexpected IOException from the passed

Modified: poi/trunk/poi-scratchpad/src/main/java/org/apache/poi/hwpf/HWPFDocumentCore.java
URL: http://svn.apache.org/viewvc/poi/trunk/poi-scratchpad/src/main/java/org/apache/poi/hwpf/HWPFDocumentCore.java?rev=1895452&r1=1895451&r2=1895452&view=diff
==============================================================================
--- poi/trunk/poi-scratchpad/src/main/java/org/apache/poi/hwpf/HWPFDocumentCore.java (original)
+++ poi/trunk/poi-scratchpad/src/main/java/org/apache/poi/hwpf/HWPFDocumentCore.java Wed Dec  1 11:33:25 2021
@@ -170,7 +170,7 @@ public abstract class HWPFDocumentCore e
     /**
      * This constructor loads a Word document from a specific point
      *  in a POIFSFileSystem, probably not the default.
-     * Used typically to open embeded documents.
+     * Used typically to open embedded documents.
      *
      * @param directory The DirectoryNode that contains the Word document.
      * @throws IOException If there is an unexpected IOException from the passed

Modified: poi/trunk/poi-scratchpad/src/test/java/org/apache/poi/hslf/extractor/TestExtractor.java
URL: http://svn.apache.org/viewvc/poi/trunk/poi-scratchpad/src/test/java/org/apache/poi/hslf/extractor/TestExtractor.java?rev=1895452&r1=1895451&r2=1895452&view=diff
==============================================================================
--- poi/trunk/poi-scratchpad/src/test/java/org/apache/poi/hslf/extractor/TestExtractor.java (original)
+++ poi/trunk/poi-scratchpad/src/test/java/org/apache/poi/hslf/extractor/TestExtractor.java Wed Dec  1 11:33:25 2021
@@ -76,7 +76,7 @@ public final class TestExtractor {
         "\nThese are the notes on page two, again lacking formatting\n";
 
     /**
-     * Where our embeded files live
+     * Where our embedded files live
      */
     private static final POIDataSamples slTests = POIDataSamples.getSlideShowInstance();
 
@@ -197,7 +197,7 @@ public final class TestExtractor {
     }
 
     /**
-     * A powerpoint file with embeded powerpoint files
+     * A powerpoint file with embedded powerpoint files
      */
     @Test
     void testExtractFromOwnEmbeded() throws IOException {
@@ -230,7 +230,7 @@ public final class TestExtractor {
     }
 
     /**
-     * A powerpoint file with embeded powerpoint files
+     * A powerpoint file with embedded powerpoint files
      */
     @Test
     void test52991() throws IOException {

Modified: poi/trunk/poi-scratchpad/src/test/java/org/apache/poi/hwpf/usermodel/TestPictures.java
URL: http://svn.apache.org/viewvc/poi/trunk/poi-scratchpad/src/test/java/org/apache/poi/hwpf/usermodel/TestPictures.java?rev=1895452&r1=1895451&r2=1895452&view=diff
==============================================================================
--- poi/trunk/poi-scratchpad/src/test/java/org/apache/poi/hwpf/usermodel/TestPictures.java (original)
+++ poi/trunk/poi-scratchpad/src/test/java/org/apache/poi/hwpf/usermodel/TestPictures.java Wed Dec  1 11:33:25 2021
@@ -139,21 +139,21 @@ public final class TestPictures {
     /**
      * When you embed another office document into Word, it stores
      * a rendered "icon" picture of what that document looks like.
-     * This image is re-created when you edit the embeded document,
+     * This image is re-created when you edit the embedded document,
      * then used as-is to speed things up.
      * Check that we can properly read one of these
      */
     @Test
     void testEmbededDocumentIcon() {
-        // This file has two embeded excel files, an embeded powerpoint
-        //   file and an embeded word file, in that order
+        // This file has two embedded excel files, an embedded powerpoint
+        //   file and an embedded word file, in that order
         HWPFDocument doc = openSampleFile("word_with_embeded.doc");
 
         // Check we don't break loading the pictures
         doc.getPicturesTable().getAllPictures();
         PicturesTable pictureTable = doc.getPicturesTable();
 
-        // Check the text, and its embeded images
+        // Check the text, and its embedded images
         Paragraph p;
         Range r = doc.getRange();
         assertEquals(1, r.numSections());

Modified: poi/trunk/poi/src/test/java/org/apache/poi/hssf/extractor/TestExcelExtractor.java
URL: http://svn.apache.org/viewvc/poi/trunk/poi/src/test/java/org/apache/poi/hssf/extractor/TestExcelExtractor.java?rev=1895452&r1=1895451&r2=1895452&view=diff
==============================================================================
--- poi/trunk/poi/src/test/java/org/apache/poi/hssf/extractor/TestExcelExtractor.java (original)
+++ poi/trunk/poi/src/test/java/org/apache/poi/hssf/extractor/TestExcelExtractor.java Wed Dec  1 11:33:25 2021
@@ -275,10 +275,10 @@ final class TestExcelExtractor {
     }
 
     /**
      * Excel embeded in excel
      */
     @Test
-    void testWithEmbededInOwn() throws Exception {
+    void testWithEmbeddedInOwn() throws Exception {
         POIDataSamples ssSamples = POIDataSamples.getSpreadSheetInstance();
         POIFSFileSystem fs = null;
         HSSFWorkbook wbA = null, wbB = null;



---------------------------------------------------------------------
@@ -275,10 +275,10 @@ final class TestExcelExtractor {
 
     /**
-     * Excel embeded in excel
+     * Excel embedded in excel
      */
     @Test
To unsubscribe, e-mail: commits-unsubscribe@poi.apache.org
For additional commands, e-mail: commits-help@poi.apache.org